@@ -15,13 +15,16 @@
 #' are then stored as .RData. The saved files are of the format team1-team2-date.RData
 #' For e.g. England-India-2008-04-06.RData etc
 #' @usage
-#' convertAllYaml2RDataframesT20(sourceDir=".",targetDir=".")
+#' convertAllYaml2RDataframesT20(sourceDir=".",targetDirMen=".",targetDirWomen=".")
 #'
 #' @param sourceDir
 #' The source directory of the yaml files
 #'
-#' @param targetDir
-#' The target directory in which the data frames are stored as RData files
+#' @param targetDirMen
+#' The target directory in which the data frames of men are stored as RData files
+#'
+#' @param targetDirWomen
+#' The target directory in which the data frames of women are stored as RData files
 #'
 #' @return None
 #' @references
@@ -47,9 +50,11 @@
 #' @export
 #'
 
-convertAllYaml2RDataframesT20 <- function(sourceDir=".",targetDir="."){
+convertAllYaml2RDataframesT20 <- function(sourceDir=".",targetDirMen=".",targetDirWomen="."){
     yaml.load_file=info.dates=info.match_type=info.overs=info.venue=NULL
-    info.teams=matchType=winner=result=venue=NULL
+    info.teams=matchType=winner=result=venue=info.gender=ball=team=batsman=NULL
+    bowler=nonStriker=byes=legbyes=noballs=wides=nonBoundary=penalty=runs=extras=totalRuns=NULL
+    wicketFielder=wicketKind=wicketPlayerOut=replacementIn=replacementOut=replacementReason=replacementRole=NULL
     files <- list.files(sourceDir)
     print(length(files))
     for(iii in 1:length(files)){
@@ -63,15 +68,12 @@ convertAllYaml2RDataframesT20 <- function(sourceDir=".",targetDir="."){
         a <- yaml.load_file(pth)
 
         # Cast as data frame for easy processing
-        #b <- as.data.frame(a)
-
-        errfiles <- NULL
-        ee<-1
         tryCatch(b <- as.data.frame(a),
                  error = function(e) {
                      print("Error!")
-                     print(pth)
-                     write(pth,"C:\\software\\cricket-package\\cricsheet\\cleanup\\T20\\files.txt",append=TRUE)
+                     eFile <- files[iii]
+                     errorFile <- paste(targetDirMen,"/","errors.txt",sep="")
+                     write(eFile,errorFile,append=TRUE)
 
                  }
         )
@@ -79,8 +81,8 @@ convertAllYaml2RDataframesT20 <- function(sourceDir=".",targetDir="."){
 
         # Gather the meta information
         meta <- select(b,info.dates,info.match_type,info.overs, info.venue,
-                       info.teams)
-        names(meta) <- c("date","matchType","overs","venue","team1")
+                       info.teams,info.gender)
+        names(meta) <- c("date","matchType","overs","venue","team1","gender")
 
         # Check if there was a winner or if there was no result (tie,draw)
         if(!is.null(b$info.outcome.winner)){
@@ -97,28 +99,18 @@ convertAllYaml2RDataframesT20 <- function(sourceDir=".",targetDir="."){
         meta <- meta[1,]
 
         #Reorder columns
-        meta <- select(meta,date,matchType,overs,venue,team1,team2,winner,result)
+        meta <- select(meta,date,matchType,overs,venue,team1,team2,winner,result,gender)
 
 
         # Remove the innings and deliveries from the column names
         names(b) <-gsub("innings.","",names(b))
         names(b) <- gsub("deliveries.","",names(b))
 
-        # Create an empty data frame
-        overs <- data.frame(ball=character(),team=factor(),batsman=factor(),
-                            bowler=factor(),nonStriker=factor(),byes=numeric(),
-                            legbyes=numeric(), noballs=numeric(), wides=numeric(),
-                            nonBoundary=factor(), penalty=factor(),
-                            runs=factor(),extras=factor(),totalRuns=factor(),
-                            wicketFielder=character(), wicketKind=character(),
-                            wicketPlayerOut=character(),date=factor(),
-                            matchType=factor(),
-                            overs=integer(),venue=factor(),team1=factor(),team2=factor(),
-                            winner=character(),result=character())
 
-
-        #Choose the columns which have the ball by ball detail
-        idx = which(names(b) == "1st.0.1.batsman")
+        # Fix for changed order of columns-28 Apr 2020
+        idx = which(names(b) == "1st.team") # Search for column name 1st.team
+        # Select the column after that which includes ball-by-ball detail
+        idx=idx+1
         m <- b[1,idx:sz[2]]
         #Transpose to the details of the match
         match <- t(m)
@@ -134,8 +126,8 @@ convertAllYaml2RDataframesT20 <- function(sourceDir=".",targetDir="."){
         # Create string of delivery in each over upto delivery 16 in case of no balls,
         # wides etc.
         # Note: The over can be more than .6 when you have no balls, wides etc
-        d <- c(".1",".2",".3",".4",".5",".6",".7",".8",".9",".11",".12",
-               ".13",".14",".15",".16")
+        d <- c(".1",".2",".3",".4",".5",".6",".7",".8",".9",".1",".1",
+               ".1",".1",".1",".1")
 
         m <- 1
         # Create a vector of deliveries from 0 to 50 by concatenating string
@@ -153,18 +145,45 @@ convertAllYaml2RDataframesT20 <- function(sourceDir=".",targetDir="."){
         s <- paste("1st.",delivery,"\\.",sep="")
         team1 <- b$`1st.team`[1]
         # Parse the yaml file over by over and store as a row of data
-        overs1 <- parseYamlOver(match,s,team1,overs,delivery,meta)
+        overs1 <- parseYamlOver(match,s,team1,delivery,meta)
 
 
         # Create string for 2nd team
         print("second loop")
         s1 <- paste("2nd.",delivery,"\\.",sep="")
         team2 <- b$`2nd.team`[1]
-        overs2 <- parseYamlOver(match,s1,team2,overs,delivery,meta)
+        overs2 <- parseYamlOver(match,s1,team2,delivery,meta)
 
         # Row bind the 1dst
         overs <- rbind(overs1,overs2)
 
+        colList=list("batsman"="batsman","bowler"="bowler","non_striker"="nonStriker","runs.batsman" ="runs",
+                     "runs.extras" ="extras","runs.total"="totalRuns","byes"="byes","legbyes"="legbyes","noballs"="noballs",
+                     "wides"="wides","nonBoundary"="nonBoundary","penalty" ="penalty","wicket.fielders"="wicketFielder",
+                     "wicket.kind"="wicketKind","wicket.player_out" ="wicketPlayerOut",
+                     "replacements.role.in"="replacementIn","replacements.role.out"="replacementOut",
+                     "replacements.role.reason"="replacementReason","replacements.role.role"="replacementRole",
+                     "ball"="ball","team"="team","date"="date","matchType"="matchType","overs" ="overs",
+                     "venue"="venue","team1" ="team1","team2" ="team2", "winner"="winner","result"="result",
+                     "gender"="gender")
+
+        # Get the column names for overs
+        cols <- names(overs)
+        newcols <- NULL
+        for(i in 1: length(cols)){
+            newcols <- c(newcols, colList[[cols[i]]])
+        }
+
+        # Rename the columns
+        names(overs) <- newcols
+        overs <- select(overs, ball,team,batsman,bowler,nonStriker,
+                        byes,legbyes,noballs,
+                        wides,nonBoundary,penalty, runs,
+                        extras,totalRuns,wicketFielder,
+                        wicketKind,wicketPlayerOut,
+                        replacementIn, replacementOut, replacementReason,
+                        replacementRole,date,matchType,overs,venue,team1,team2,winner,result,gender)
+
         # Change factors to appropiate type
         overs$byes <- as.numeric(as.character(overs$byes))
         overs$legbyes <- as.numeric(as.character(overs$legbyes))
@@ -177,21 +196,36 @@ convertAllYaml2RDataframesT20 <- function(sourceDir=".",targetDir="."){
         overs$totalRuns <- as.numeric(as.character(overs$totalRuns))
         overs$date = as.Date(overs$date)
         overs$overs <- as.numeric(as.character(overs$overs))
+        # Add missing elements
+        overs[overs$wicketFielder == 0,]$wicketFielder="nobody"
+        overs[overs$wicketKind == 0,]$wicketKind="not-out"
+        overs[overs$wicketPlayerOut==0,]$wicketPlayerOut ="nobody"
         sapply(overs,class)
 
         teams <- as.character(unique(overs$team))
-        print(dim(overs))
         #Create a unique file which is based on the opposing teams and the date of the match
         filename <- paste(meta$team1,"-",meta$team2,"-",meta$date,".",
                           "RData",sep="")
 
-        to <- paste(targetDir,"/",filename,sep="")
+        # Write men and women in separate folders
+        gender=overs$gender
+
+        if(gender[1] =="male"){
+            to <- paste(targetDirMen,"/",filename,sep="")
+        }
+        else{
+            to <- paste(targetDirWomen,"/",filename,sep="")
+        }
+
         # Save as .RData
         save(overs,file=to)
 
         # Write the name of the file that was converted and the converted file for reference
         convertedFile <- paste(files[iii],filename,sep=":")
-        outputFile <- paste(targetDir,"/","convertedFiles.txt",sep="")
+        if(gender[1] == "male")
+            outputFile <- paste(targetDirMen,"/","convertedFiles.txt",sep="")
+        else
+            outputFile <- paste(targetDirWomen,"/","convertedFiles.txt",sep="")
         write(convertedFile,outputFile,append=TRUE)
 
 
@@ -203,3 +237,4 @@ convertAllYaml2RDataframesT20 <- function(sourceDir=".",targetDir="."){
 
 
 
+
