@@ -1,6 +1,6 @@
 ##########################################################################################
 # Designed and developed by Tinniam V Ganesh
-# Date : 20 Mar 2016
+# Date : 2 May 2020
 # Function: convertYaml2RDataframeT20
 # This function converts a given T20 yaml file to a data frame and stores this as n .RData
 # The yaml file is read from a given source directory coverted and saved to a target directory.
@@ -54,15 +54,27 @@
 convertYaml2RDataframeT20 <- function(yamlFile,sourceDir=".",targetDir="."){
 
     yaml.load_file=info.dates=info.match_type=info.overs=info.venue=NULL
-    info.teams=matchType=winner=result=venue=NULL
+    info.teams=matchType=winner=result=venue=gender=ball=team=batsman=NULL
+    bowler=nonStriker=byes=legbyes=noballs=wides=nonBoundary=penalty=runs=extras=totalRuns=NULL
+    wicketFielder=wicketKind=wicketPlayerOut=replacementIn=replacementOut=replacementReason=replacementRole=NULL
+
     pth = paste(sourceDir,"/",yamlFile,sep="")
     print(pth)
 
     # Load yaml file
+
     a <- yaml.load_file(pth)
 
     # Cast as data frame for easy processing
-    b <- as.data.frame(a)
+    tryCatch(b <- as.data.frame(a),
+             error = function(e) {
+                 print("Error!")
+                 eFile <- yamlFile
+                 errorFile <- paste(targetDir,"/","errors.txt",sep="")
+                 write(errorFile,eFile,append=TRUE)
+
+             }
+    )
     sz <- dim(b)
 
     # Gather the meta information
@@ -93,21 +105,11 @@ convertYaml2RDataframeT20 <- function(yamlFile,sourceDir=".",targetDir="."){
     names(b) <-gsub("innings.","",names(b))
     names(b) <- gsub("deliveries.","",names(b))
 
-    # Create an empty data frame
-    overs <- data.frame(ball=character(),team=factor(),batsman=factor(),
-                        bowler=factor(),nonStriker=factor(),byes=numeric(),
-                        legbyes=numeric(), noballs=numeric(), wides=numeric(),
-                        nonBoundary=factor(), penalty=factor(),
-                        runs=factor(),extras=factor(),totalRuns=factor(),
-                        wicketFielder=character(), wicketKind=character(),
-                        wicketPlayerOut=character(),date=factor(),
-                        matchType=factor(),
-                        overs=integer(),venue=factor(),team1=factor(),team2=factor(),
-                        winner=character(),result=character())
 
-
-    #Choose the columns which have the ball by ball detail
-    idx = which(names(b) == "1st.0.1.batsman")
+    # Fix for changed order of columns-28 Apr 2020
+    idx = which(names(b) == "1st.team") # Search for column name 1st.team
+    # Select the column after that which includes ball-by-ball detail
+    idx=idx+1
     m <- b[1,idx:sz[2]]
     #Transpose to the details of the match
     match <- t(m)
@@ -123,8 +125,8 @@ convertYaml2RDataframeT20 <- function(yamlFile,sourceDir=".",targetDir="."){
     # Create string of delivery in each over upto delivery 16 in case of no balls,
     # wides etc.
     # Note: The over can be more than .6 when you have no balls, wides etc
-    d <- c(".1",".2",".3",".4",".5",".6",".7",".8",".9",".11",".12",
-           ".13",".14",".15",".16")
+    d <- c(".1",".2",".3",".4",".5",".6",".7",".8",".9",".1",".1",
+           ".1",".1",".1",".1")
 
     m <- 1
     # Create a vector of deliveries from 0 to 50 by concatenating string
@@ -136,24 +138,51 @@ convertYaml2RDataframeT20 <- function(yamlFile,sourceDir=".",targetDir="."){
         }
     }
 
-
     #Create string for 1st team
     print("first loop")
     s <- paste("1st.",delivery,"\\.",sep="")
     team1 <- b$`1st.team`[1]
     # Parse the yaml file over by over and store as a row of data
-    overs1 <- parseYamlOver(match,s,team1,overs,delivery,meta)
+    overs1 <- parseYamlOver(match,s,team1,delivery,meta)
 
 
     # Create string for 2nd team
     print("second loop")
     s1 <- paste("2nd.",delivery,"\\.",sep="")
     team2 <- b$`2nd.team`[1]
-    overs2 <- parseYamlOver(match,s1,team2,overs,delivery,meta)
+    overs2 <- parseYamlOver(match,s1,team2,delivery,meta)
 
     # Row bind the 1dst
     overs <- rbind(overs1,overs2)
 
+
+    # Fix for changed order of columns-28 Apr 2020
+    colList=list("batsman"="batsman","bowler"="bowler","non_striker"="nonStriker","runs.batsman" ="runs",
+                 "runs.extras" ="extras","runs.total"="totalRuns","byes"="byes","legbyes"="legbyes","noballs"="noballs",
+                 "wides"="wides","nonBoundary"="nonBoundary","penalty" ="penalty","wicket.fielders"="wicketFielder",
+                 "wicket.kind"="wicketKind","wicket.player_out" ="wicketPlayerOut",
+                 "replacements.role.in"="replacementIn","replacements.role.out"="replacementOut",
+                 "replacements.role.reason"="replacementReason","replacements.role.role"="replacementRole",
+                 "ball"="ball","team"="team","date"="date","matchType"="matchType","overs" ="overs",
+                 "venue"="venue","team1" ="team1","team2" ="team2", "winner"="winner","result"="result")
+
+    # Get the column names for overs
+    cols <- names(overs)
+    newcols <- NULL
+    for(i in 1: length(cols)){
+        newcols <- c(newcols, colList[[cols[i]]])
+    }
+
+    # Rename the columns
+    names(overs) <- newcols
+    overs <- select(overs, ball,team,batsman,bowler,nonStriker,
+                    byes,legbyes,noballs,
+                    wides,nonBoundary,penalty, runs,
+                    extras,totalRuns,wicketFielder,
+                    wicketKind,wicketPlayerOut,
+                    replacementIn, replacementOut, replacementReason,
+                    replacementRole,date,matchType,overs,venue,team1,team2,winner,result)
+
     # Change factors to appropiate type
     overs$byes <- as.numeric(as.character(overs$byes))
     overs$legbyes <- as.numeric(as.character(overs$legbyes))
@@ -166,6 +195,11 @@ convertYaml2RDataframeT20 <- function(yamlFile,sourceDir=".",targetDir="."){
     overs$totalRuns <- as.numeric(as.character(overs$totalRuns))
     overs$date = as.Date(overs$date)
     overs$overs <- as.numeric(as.character(overs$overs))
+    # Add missing elements
+    overs[overs$wicketFielder == 0,]$wicketFielder="nobody"
+    overs[overs$wicketKind == 0,]$wicketKind="not-out"
+    overs[overs$wicketPlayerOut==0,]$wicketPlayerOut ="nobody"
+
     sapply(overs,class)
 
 
@@ -187,4 +221,3 @@ convertYaml2RDataframeT20 <- function(yamlFile,sourceDir=".",targetDir="."){
 
 
 
-
